Check if R has access to resources at https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Check if R has access to resources at https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Site built with pkgdown 2.2.0.
Template rostemplate by dieghernan, based on Universal Theme for Hugo.