esp_get_attributions: Get the attribution for a tile provider

View source: R/esp-get-attributions.R

esp_get_attributionsR Documentation

Get the attribution for a tile provider

Description

esp_get_attributions() returns the attribution for a tile provider defined by the type argument.

Usage

esp_get_attributions(type, options = NULL)

Arguments

type

This argument can be one of:

  • The name of one of the pre-defined providers (see esp_tiles_providers).

  • A list with two named elements id and q with your own arguments. See esp_make_provider() and examples.

options

A named list containing additional options to pass to the query.

Value

A character string with the provider attribution, or NULL if no attribution is available.

See Also

  • esp_get_tiles() downloads static map tiles.

  • giscoR::gisco_attributions() provides GISCO attribution text.

Static map tiles and imagery: addProviderEspTiles(), esp_get_tiles(), esp_make_provider()

Examples

esp_get_attributions("IGNBase.Todo")

mapSpain documentation built on Aug. 31, 2026, 5:07 p.m.