View source: R/esp-get-capimun.R
| esp_get_capimun | R Documentation |
This function returns an sf POINT object that locates the
seat of government for each municipality.
Note that this differs from the centroid of the boundaries of the
municipality, returned by esp_get_munic_siane().
esp_get_capimun(
year = Sys.Date(),
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
region = NULL,
munic = NULL,
moveCAN = TRUE,
rawcols = FALSE
)
year |
Character string or number. Release year. It must use format
|
epsg |
Character string or number. Projection of the map: 4-digit EPSG code. One of:
|
cache |
Logical. Whether to cache downloaded files. Defaults to |
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
region |
Optional. A vector of region names, NUTS or ISO codes
(see |
munic |
Character string. A name or |
moveCAN |
A logical |
rawcols |
Logical. If |
When using region you can use and mix names and NUTS codes (levels 1, 2 or
3), ISO codes (corresponding to level 2 or 3) or "cpro"
(see esp_codelist).
When calling a higher level, such as a province, Autonomous Community, Autonomous City or NUTS 1 region, all municipalities of that level are added.
An sf POINT object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
CartoBase ANE boundaries and utilities:
esp_get_ccaa_siane(),
esp_get_countries_siane(),
esp_get_munic_siane(),
esp_get_prov_siane(),
esp_get_spain_siane(),
esp_siane_bulk_download()
Municipality-level datasets:
esp_get_munic(),
esp_get_munic_siane()
# Compare municipality centroids against municipal seats of government.
# Get the municipality boundary.
area <- esp_get_munic_siane(munic = "Valladolid", epsg = 3857)
# Area in km2.
print(paste0(round(as.double(sf::st_area(area)) / 1000000, 2), " km2"))
# Extract the centroid.
centroid <- sf::st_centroid(area)
centroid$type <- "Centroid"
# Compare with capimun.
capimun <- esp_get_capimun(munic = "Valladolid", epsg = 3857)
capimun$type <- "Capimun"
# Join both point geometries.
points <- dplyr::bind_rows(centroid, capimun)
# Check on a plot.
library(ggplot2)
ggplot(points) +
geom_sf(data = area, fill = NA, color = "blue") +
geom_sf(data = points, aes(fill = type), size = 5, shape = 21) +
scale_fill_manual(values = c("green", "red")) +
labs(title = "Centroid vs. capimun")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.