View source: R/esp-get-grid-EEA.R
| esp_get_grid_EEA | R Documentation |
This function is defunct because the source file is no longer available.
esp_get_grid_EEA(
resolution = 100,
type = "main",
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
resolution |
Resolution of the grid in kilometers. Can be |
type |
Character. The geographic scope of the grid:
|
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
An sf POLYGON object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.