esp_get_grid_ESDAC: National geographic grids from the European Soil Data Centre...

View source: R/esp-get-grid-ESDAC.R

esp_get_grid_ESDACR Documentation

National geographic grids from the European Soil Data Centre (ESDAC)

Description

This function loads an sf POLYGON with the geographic grids of Spain provided by the European Soil Data Centre (ESDAC).

Usage

esp_get_grid_ESDAC(
  resolution = c(10, 1),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

resolution

Numeric. Resolution of the grid in kilometers. Can be 1 or 10.

update_cache

Logical. If TRUE, refreshes the cached file and forces a new download. Defaults to FALSE.

cache_dir

Character string. A path to a cache directory. See Caching.

verbose

A logical value indicating whether to display informational messages.

Value

An sf POLYGON object.

Caching

Functions that download data store files in cache_dir. When cache_dir is NULL, they use the active package cache, which defaults to a temporary directory. Set update_cache = TRUE to replace an existing cached file. See Caching strategies in esp_set_cache_dir() to configure a persistent cache.

EEA reference grid.

References

  • Panagos P., Van Liedekerke M., Jones A., Montanarella L., "European Soil Data Centre: Response to European policy support and public data requirements", (2012) Land Use Policy, 29 (2), pp. 329-338. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.landusepol.2011.07.003")}.

  • European Soil Data Centre (ESDAC), esdac.jrc.ec.europa.eu, European Commission, Joint Research Centre.

See Also

Geographic grid data: esp_get_grid_BDN(), esp_get_grid_MTN()

Examples


## Not run: 
grid <- esp_get_grid_ESDAC()
esp <- esp_get_spain(moveCAN = FALSE)

library(ggplot2)

ggplot(grid) +
  geom_sf() +
  geom_sf(data = esp, color = "grey50", fill = NA) +
  theme_light() +
  labs(title = "ESDAC Grid for Spain")

## End(Not run)


mapSpain documentation built on Aug. 31, 2026, 5:07 p.m.