View source: R/esp-get-grid-MTN.R
| esp_get_grid_MTN | R Documentation |
This function loads an sf POLYGON with the geographic
grids of Spain.
esp_get_grid_MTN(
grid = "MTN25_ETRS89_Peninsula_Baleares_Canarias",
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
grid |
Name of the grid to be loaded. See Details. |
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
Metadata available on https://github.com/rOpenSpain/mapSpain/tree/sianedata/MTN.
Possible values of grid are:
| grid_name |
| MTN25_ED50_Peninsula_Baleares |
| MTN25_ETRS89_ceuta_melilla_alboran |
| MTN25_ETRS89_Peninsula_Baleares_Canarias |
| MTN25_RegCan95_Canarias |
| MTN50_ED50_Peninsula_Baleares |
| MTN50_ETRS89_Peninsula_Baleares_Canarias |
| MTN50_RegCan95_Canarias |
A description of the available MTN (Mapa Topográfico Nacional) grids:
MTN25_ED50_Peninsula_Baleares
MTN25 grid corresponding to the Peninsula and Balearic Islands, in ED50 and geographical coordinates (longitude, latitude). This is the real MTN25 grid, that is, the one that divides the current printed series of the map, taking into account special sheets and irregularities.
MTN50_ED50_Peninsula_Baleares
MTN50 grid corresponding to the Peninsula and Balearic Islands, in ED50 and geographical coordinates (longitude, latitude). This is the real MTN50 grid, that is, the one that divides the current printed series of the map, taking into account special sheets and irregularities.
MTN25_ETRS89_ceuta_melilla_alboran
MTN25 grid corresponding to Ceuta, Melilla, Alboran and Spanish territories in North Africa, adjusted to the new official geodetic reference system ETRS89, in geographical coordinates (longitude, latitude).
MTN25_ETRS89_Peninsula_Baleares_Canarias
MTN25 real grid corresponding to the Peninsula, the Balearic Islands and the Canary Islands, adjusted to the new ETRS89 official reference geodetic system, in geographical coordinates (longitude, latitude).
MTN50_ETRS89_Peninsula_Baleares_Canarias
MTN50 real grid corresponding to the Peninsula, the Balearic Islands and the Canary Islands, adjusted to the new ETRS89 official reference geodetic system, in geographical coordinates (longitude, latitude).
MTN25_RegCan95_Canarias
MTN25 grid corresponding to the Canary Islands, in REGCAN95 (WGS84 compatible) and geographic coordinates (longitude, latitude). It is the real MTN25 grid, that is, the one that divides the current printed series of the map, taking into account the special distribution of the Canary Islands sheets.
MTN50_RegCan95_Canarias
MTN50 grid corresponding to the Canary Islands, in REGCAN95 (WGS84 compatible) and geographic coordinates (longitude, latitude). This is the real grid of the MTN50, that is, the one that divides the current printed series of the map, taking into account the special distribution of the Canary Islands sheets.
An sf POLYGON object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
IGN data distributed through the sianedata/MTN data branch (see
https://github.com/rOpenSpain/mapSpain/tree/sianedata/MTN).
Geographic grid data:
esp_get_grid_BDN(),
esp_get_grid_ESDAC()
grid <- esp_get_grid_MTN(grid = "MTN50_ETRS89_Peninsula_Baleares_Canarias")
library(ggplot2)
ggplot(grid) +
geom_sf() +
theme_light() +
labs(title = "MTN50 Grid for Spain")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.