| esp_get_landwater | R Documentation |
This dataset represents rivers, lagoons, reservoirs and wetlands in Spain.
esp_get_rivers(
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
resolution = deprecated(),
spatialtype = c("line", "area"),
moveCAN = TRUE,
name = NULL
)
esp_get_wetlands(
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
moveCAN = TRUE,
name = NULL
)
epsg |
Character string or number. Projection of the map: 4-digit EPSG code. One of:
|
cache |
Logical. Whether to cache downloaded files. Defaults to |
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
resolution |
|
spatialtype |
|
moveCAN |
A logical |
name |
Character string or |
Metadata available on https://github.com/rOpenSpain/mapSpain/tree/sianedata/.
A sf object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Natural feature datasets:
esp_get_hydrobasin(),
esp_get_hypsobath()
# Use of regex.
regex1 <- esp_get_rivers(name = "Tajo|Segura")
unique(regex1$rotulo)
regex2 <- esp_get_rivers(name = "Tajo$| Segura")
unique(regex2$rotulo)
# See the difference.
# Rivers in Spain.
iberian <- giscoR::gisco_get_countries(
country = c("ES", "PT", "FR"), resolution = 3
)
main_rivers <- esp_get_rivers() |>
dplyr::filter(t_rio == 1)
library(ggplot2)
ggplot(iberian) +
geom_sf() +
geom_sf(data = main_rivers, color = "skyblue", linewidth = 2) +
coord_sf(
xlim = c(-10, 5),
ylim = c(35, 44)
)
# Wetlands in South-West Andalucia.
and <- esp_get_prov(c("Huelva", "Sevilla", "Cadiz"))
wetlands <- esp_get_wetlands()
wetlands_south <- sf::st_filter(wetlands, and)
ggplot(and) +
geom_sf() +
geom_sf(
data = wetlands_south, fill = "skyblue",
color = "skyblue", alpha = 0.5
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.