| esp_get_prov | R Documentation |
Return provinces of Spain at a specified scale.
esp_get_prov(prov = NULL, moveCAN = TRUE, ...)
prov |
A vector of names, codes or both for provinces, or |
moveCAN |
A logical |
... |
Arguments passed on to
|
When using prov you can use and mix names and NUTS codes (levels 1, 2 or
3), ISO codes (corresponding to level 2 or 3) or "cpro" (see
esp_codelist).
Ceuta and Melilla are considered provinces in this dataset.
When calling a higher level, such as an Autonomous Community, Autonomous City or NUTS 1 region, all provinces of that level are added.
A sf object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
GISCO NUTS distribution API: https://gisco-services.ec.europa.eu/distribution/v2/nuts/.
esp_get_prov_siane().
GISCO boundary data:
esp_get_ccaa(),
esp_get_munic(),
esp_get_nuts(),
esp_get_spain()
prov <- esp_get_prov()
library(ggplot2)
ggplot(prov) +
geom_sf() +
theme_minimal()
# Random provinces.
random <- esp_get_prov(prov = c(
"Zamora", "Palencia", "ES-GR",
"ES521", "01"
))
ggplot(random) +
geom_sf(aes(fill = codauto), show.legend = FALSE, alpha = 0.5) +
scale_fill_manual(values = hcl.colors(nrow(random), "Spectral")) +
theme_minimal()
# All provinces of a zone plus one addition.
mix <- esp_get_prov(prov = c(
"Noroeste",
"Castilla y Leon", "La Rioja"
))
mix$ccaa <- esp_dict_region_code(
mix$codauto,
origin = "codauto"
)
ggplot(mix) +
geom_sf(aes(fill = ccaa), alpha = 0.5) +
scale_fill_discrete(type = hcl.colors(5, "Temps")) +
theme_classic()
# Available ISO codes.
allprovs <- esp_get_prov()
ggplot(allprovs) +
geom_sf(fill = NA) +
geom_sf_text(aes(label = iso2.prov.code),
check_overlap = TRUE,
fontface = "bold"
) +
coord_sf(crs = 3857) +
theme_void()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.