View source: R/esp-get-railway.R
| esp_get_railway | R Documentation |
This function loads an sf LINESTRING or POINT object
representing the nodes and railway lines of Spain.
esp_get_railway(
year = Sys.Date(),
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
spatialtype = c("line", "point")
)
esp_get_stations(
year = Sys.Date(),
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)
year |
Ignored. |
epsg |
Character string or number. Projection of the map: 4-digit EPSG code. One of:
|
cache |
Logical. Whether to cache downloaded files. Defaults to |
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
spatialtype |
|
A sf object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Transport infrastructure datasets:
esp_get_roads()
provs <- esp_get_prov()
ccaa <- esp_get_ccaa()
# Railways.
rails <- esp_get_railway()
# Stations.
stations <- esp_get_stations()
# Map.
library(ggplot2)
ggplot(provs) +
geom_sf(fill = "grey99", color = "grey50") +
geom_sf(data = ccaa, fill = NA) +
geom_sf(
data = rails, aes(color = t_ffcc_desc),
show.legend = FALSE,
linewidth = 1.5
) +
geom_sf(
data = stations,
color = "red", alpha = 0.5
) +
scale_colour_viridis_d() +
facet_wrap(~t_ffcc_desc) +
theme_minimal()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.