esp_get_spain: Boundaries of Spain from GISCO

View source: R/esp-get-spain.R

esp_get_spainR Documentation

Boundaries of Spain from GISCO

Description

Returns the boundaries of Spain as a single sf POLYGON at a specified scale.

Usage

esp_get_spain(moveCAN = TRUE, ...)

Arguments

moveCAN

A logical TRUE/FALSE or a vector of coordinates c(lat, lon). It places the Canary Islands close to Spain's mainland. Initial position can be adjusted using the vector of coordinates. See Displacing the Canary Islands in esp_move_can().

...

Arguments passed on to esp_get_nuts

year

Year character string or number. Release year of the file. See giscoR::gisco_get_nuts() for valid values.

epsg

Character string or number. Projection of the map: 4-digit EPSG code. One of:

cache

Logical. Whether to cache downloaded files. Defaults to TRUE. See Caching.

update_cache

Logical. If TRUE, refreshes the cached file and forces a new download. Defaults to FALSE.

cache_dir

Character string. A path to a cache directory. See Caching.

ext

Character. Extension of the file (default "gpkg"). See giscoR::gisco_get_nuts().

verbose

A logical value indicating whether to display informational messages.

resolution

A character string or numeric value with the geospatial data resolution. One of:

  • "60": 1:60 million.

  • "20": 1:20 million.

  • "10": 1:10 million.

  • "03": 1:3 million.

  • "01": 1:1 million.

Details

Dataset derived from NUTS data provided by GISCO. Check esp_get_nuts() for details.

Value

A sf POLYGON object.

Caching

Functions that download data store files in cache_dir. When cache_dir is NULL, they use the active package cache, which defaults to a temporary directory. Set update_cache = TRUE to replace an existing cached file. See Caching strategies in esp_set_cache_dir() to configure a persistent cache.

GISCO NUTS distribution API: https://gisco-services.ec.europa.eu/distribution/v2/nuts/.

See Also

esp_get_spain_siane().

NUTS boundary datasets: esp_get_nuts()

GISCO boundary data: esp_get_ccaa(), esp_get_munic(), esp_get_nuts(), esp_get_prov()

Examples



original_can <- esp_get_spain(moveCAN = FALSE)

# One row only.
original_can

library(ggplot2)

ggplot(original_can) +
  geom_sf(fill = "grey70")

# Less resolution.
moved_can <- esp_get_spain(moveCAN = TRUE, resolution = 20)

ggplot(moved_can) +
  geom_sf(fill = "grey70")



mapSpain documentation built on Aug. 31, 2026, 5:07 p.m.