esp_nuts_2024: NUTS 2024 boundaries for Spain

esp_nuts_2024R Documentation

NUTS 2024 boundaries for Spain

Description

This dataset represents Spanish subdivisions at NUTS levels 0, 1, 2 and 3 according to the Nomenclature of Territorial Units for Statistics (NUTS) classification for 2024.

Format

An sf object with MULTIPOLYGON geometries at 1:1 million resolution in EPSG:4258 projection, containing 86 rows and 10 variables:

NUTS_ID

NUTS identifier.

LEVL_CODE

NUTS level code (0, 1, 2 or 3).

CNTR_CODE

Eurostat country code.

NAME_LATN

NUTS name in Latin characters.

NUTS_NAME

NUTS name in the local alphabet.

MOUNT_TYPE

Mountain type, see Details.

URBN_TYPE

Urban type, see Details.

COAST_TYPE

Coastal type, see Details.

geo

Same as NUTS_ID, provided for compatibility with eurostat.

geometry

Geometry field.

Details

MOUNT_TYPE: Mountain typology:

  • 1: More than 50 % of the surface is covered by topographic mountain areas.

  • 2: More than 50 % of the regional population lives in topographic mountain areas.

  • 3: More than 50 % of the surface is covered by topographic mountain areas and where more than 50 % of the regional population lives in these mountain areas.

  • 4: Non-mountain region / other regions.

  • 0: No classification provided.

URBN_TYPE: Urban-rural typology:

  • 1: Predominantly urban region.

  • 2: Intermediate region.

  • 3: Predominantly rural region.

  • 0: No classification provided.

COAST_TYPE: Coastal typology:

  • 1: Coastal (on coast).

  • 2: Coastal (less than 50 % of population living within 50 km of the coastline).

  • 3: Non-coastal region.

  • 0: No classification provided.

NUTS_RG_01M_2024_4326.gpkg file.

See Also

esp_get_nuts().

Included package datasets: esp_codelist, esp_tiles_providers, pobmun25

Examples

data("esp_nuts_2024")
head(esp_nuts_2024)


mapSpain documentation built on Aug. 31, 2026, 5:07 p.m.