esp_siane_bulk_download: SIANE bulk download

View source: R/esp-siane-bulk-download.R

esp_siane_bulk_downloadR Documentation

SIANE bulk download

Description

This function downloads zipped data from SIANE to cache_dir and extracts the relevant files.

Usage

esp_siane_bulk_download(
  cache_dir = NULL,
  update_cache = FALSE,
  verbose = FALSE
)

Arguments

cache_dir

Character string. A path to a cache directory. See Caching.

update_cache

Logical. If TRUE, refreshes the cached file and forces a new download. Defaults to FALSE.

verbose

A logical value indicating whether to display informational messages.

Value

An invisible character vector with the full paths of the extracted files. See Examples.

Caching

Functions that download data store files in cache_dir. When cache_dir is NULL, they use the active package cache, which defaults to a temporary directory. Set update_cache = TRUE to replace an existing cached file. See Caching strategies in esp_set_cache_dir() to configure a persistent cache.

CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.

Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane

Always acknowledge authorship using the following statements:

  1. When the original digital product is not modified or altered, use one of the following statements:

    • CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.

    • CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.

  2. When a new product is generated:

    • Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.

Data distributed through the sianedata data branch, see https://github.com/rOpenSpain/mapSpain/tree/sianedata.

See Also

CartoBase ANE boundaries and utilities: esp_get_capimun(), esp_get_ccaa_siane(), esp_get_countries_siane(), esp_get_munic_siane(), esp_get_prov_siane(), esp_get_spain_siane()

Examples


tmp <- file.path(tempdir(), "testexample")
dest_files <- esp_siane_bulk_download(cache_dir = tmp)

# Read one file.
library(sf)
read_sf(dest_files[1]) |> head()

# Connect the function with the downloaded data.

invisible(esp_get_munic_siane(cache_dir = tmp, verbose = TRUE))

# The message shows that the file is already cached.

# Clean up.
unlink(tmp, force = TRUE, recursive = TRUE)


mapSpain documentation built on Aug. 31, 2026, 5:07 p.m.