| esp_codelist | R Documentation |
A tibble object used internally to translate codes and names for different Spanish subdivisions. This tibble provides a hierarchical representation of Spain's subdivisions, including NUTS 1, Autonomous Communities and Cities (equivalent to NUTS 2), provinces and province-level NUTS 3 units. See the note below for coverage details.
A tibble with 59 rows and columns:
NUTS 1 code.
NUTS 1 name.
NUTS 1 alternative name.
NUTS 1 short (common) name (Spanish).
INE code of the Autonomous Community or City.
ISO2 code of the Autonomous Community or City.
NUTS 2 code.
INE name of the Autonomous Community or City.
ISO2 name of the Autonomous Community or City (Spanish).
ISO2 name of the Autonomous Community or City (Catalan).
ISO2 name of the Autonomous Community or City (Galician).
ISO2 name of the Autonomous Community or City (Basque).
NUTS 2 name.
CLDR name of the Autonomous Community or City (English).
CLDR name of the Autonomous Community or City (Spanish).
CLDR name of the Autonomous Community or City (Catalan).
CLDR name of the Autonomous Community or City (Galician).
CLDR name of the Autonomous Community or City (Basque).
Short (common) name of the subdivision (English).
Short (common) name of the subdivision (Spanish).
Short (common) name of the subdivision (Catalan).
Short (common) name of the subdivision (Galician).
Short (common) name of the subdivision (Basque).
INE code of the province.
ISO2 code of the province.
NUTS code of the province.
INE name of the province.
ISO2 name of the province (Spanish).
ISO2 name of the province (Catalan).
ISO2 name of the province (Galician).
ISO2 name of the province (Basque).
CLDR name of the province (English).
CLDR name of the province (Spanish).
CLDR name of the province (Catalan).
CLDR name of the province (Galician).
CLDR name of the province (Basque).
Short (common) name of the province (English).
Short (common) name of the province (Spanish).
Short (common) name of the province (Catalan).
Short (common) name of the province (Galician).
Short (common) name of the province (Basque).
NUTS 3 code.
NUTS 3 name.
NUTS 3 short (common) name.
Although NUTS 2 aligns with the first subdivision level of Spain (Autonomous Communities and Cities), NUTS 3 does not correspond to the second subdivision level of Spain (provinces). NUTS 3 provides dedicated codes for major islands, whereas provinces do not.
Ceuta and Melilla have special status as Autonomous Cities but are represented at the Autonomous Communities and Cities level with a single province, like Madrid, Asturias or Murcia, in this database.
INE: Instituto Nacional de Estadística, https://www.ine.es/.
Eurostat (NUTS): https://ec.europa.eu/eurostat/web/nuts/overview.
CLDR: https://www.unicode.org/cldr/charts/48/subdivisionNames/index.html
esp_dict_region_code().
Included package datasets:
esp_nuts_2024,
esp_tiles_providers,
pobmun25
data("esp_codelist")
esp_codelist
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.