Skip to contents

A tibble object used internally to translate codes and names for different Spanish subdivisions. This tibble provides a hierarchical representation of Spain's subdivisions, including NUTS 1, Autonomous Communities and Cities (equivalent to NUTS 2), provinces and province-level NUTS 3 units. See the note below for coverage details.

Format

A tibble with 59 rows and columns:

nuts1.code

NUTS 1 code.

nuts1.name

NUTS 1 name.

nuts1.name.alt

NUTS 1 alternative name.

nuts1.shortname.es

NUTS 1 short (common) name (Spanish).

codauto

INE code of the Autonomous Community or City.

iso2.ccaa.code

ISO2 code of the Autonomous Community or City.

nuts2.code

NUTS 2 code.

ine.ccaa.name

INE name of the Autonomous Community or City.

iso2.ccaa.name.es

ISO2 name of the Autonomous Community or City (Spanish).

iso2.ccaa.name.ca

ISO2 name of the Autonomous Community or City (Catalan).

iso2.ccaa.name.gl

ISO2 name of the Autonomous Community or City (Galician).

iso2.ccaa.name.eu

ISO2 name of the Autonomous Community or City (Basque).

nuts2.name

NUTS 2 name.

cldr.ccaa.name.en

CLDR name of the Autonomous Community or City (English).

cldr.ccaa.name.es

CLDR name of the Autonomous Community or City (Spanish).

cldr.ccaa.name.ca

CLDR name of the Autonomous Community or City (Catalan).

cldr.ccaa.name.ga

CLDR name of the Autonomous Community or City (Galician).

cldr.ccaa.name.eu

CLDR name of the Autonomous Community or City (Basque).

ccaa.shortname.en

Short (common) name of the subdivision (English).

ccaa.shortname.es

Short (common) name of the subdivision (Spanish).

ccaa.shortname.ca

Short (common) name of the subdivision (Catalan).

ccaa.shortname.ga

Short (common) name of the subdivision (Galician).

ccaa.shortname.eu

Short (common) name of the subdivision (Basque).

cpro

INE code of the province.

iso2.prov.code

ISO2 code of the province.

nuts.prov.code

NUTS code of the province.

ine.prov.name

INE name of the province.

iso2.prov.name.es

ISO2 name of the province (Spanish).

iso2.prov.name.ca

ISO2 name of the province (Catalan).

iso2.prov.name.ga

ISO2 name of the province (Galician).

iso2.prov.name.eu

ISO2 name of the province (Basque).

cldr.prov.name.en

CLDR name of the province (English).

cldr.prov.name.es

CLDR name of the province (Spanish).

cldr.prov.name.ca

CLDR name of the province (Catalan).

cldr.prov.name.ga

CLDR name of the province (Galician).

cldr.prov.name.eu

CLDR name of the province (Basque).

prov.shortname.en

Short (common) name of the province (English).

prov.shortname.es

Short (common) name of the province (Spanish).

prov.shortname.ca

Short (common) name of the province (Catalan).

prov.shortname.ga

Short (common) name of the province (Galician).

prov.shortname.eu

Short (common) name of the province (Basque).

nuts3.code

NUTS 3 code.

nuts3.name

NUTS 3 name.

nuts3.shortname.es

NUTS 3 short (common) name.

Note

Although NUTS 2 aligns with the first subdivision level of Spain (Autonomous Communities and Cities), NUTS 3 does not correspond to the second subdivision level of Spain (provinces). NUTS 3 provides dedicated codes for major islands, whereas provinces do not.

Ceuta and Melilla have special status as Autonomous Cities but are represented at the Autonomous Communities and Cities level with a single province, like Madrid, Asturias or Murcia, in this database.

See also

Included package datasets: esp_nuts_2024, esp_tiles_providers, pobmun25

Examples


data("esp_codelist")
esp_codelist
#> # A tibble: 59 × 44
#>    nuts1.code nuts1.name nuts1.name.alt nuts1.shortname.es codauto
#>    <chr>      <chr>      <chr>          <chr>              <chr>  
#>  1 ES1        Noroeste   Noroeste       Noroeste           03     
#>  2 ES1        Noroeste   Noroeste       Noroeste           06     
#>  3 ES1        Noroeste   Noroeste       Noroeste           12     
#>  4 ES1        Noroeste   Noroeste       Noroeste           12     
#>  5 ES1        Noroeste   Noroeste       Noroeste           12     
#>  6 ES1        Noroeste   Noroeste       Noroeste           12     
#>  7 ES2        Noreste    Noreste        Noreste            02     
#>  8 ES2        Noreste    Noreste        Noreste            02     
#>  9 ES2        Noreste    Noreste        Noreste            02     
#> 10 ES2        Noreste    Noreste        Noreste            15     
#> # ℹ 49 more rows
#> # ℹ 39 more variables: iso2.ccaa.code <chr>, nuts2.code <chr>,
#> #   ine.ccaa.name <chr>, iso2.ccaa.name.es <chr>, iso2.ccaa.name.ca <chr>,
#> #   iso2.ccaa.name.gl <chr>, iso2.ccaa.name.eu <chr>, nuts2.name <chr>,
#> #   cldr.ccaa.name.en <chr>, cldr.ccaa.name.es <chr>, cldr.ccaa.name.ca <chr>,
#> #   cldr.ccaa.name.ga <chr>, cldr.ccaa.name.eu <chr>, ccaa.shortname.en <chr>,
#> #   ccaa.shortname.es <chr>, ccaa.shortname.ca <chr>, …