View source: R/esp-get-attributions.R
| esp_get_attributions | R Documentation |
esp_get_attributions() returns the attribution for a tile provider defined
by the type argument.
esp_get_attributions(type, options = NULL)
type |
This argument can be one of:
|
options |
A named list containing additional options to pass to the query. |
A character string with the provider attribution, or NULL if no
attribution is available.
esp_get_tiles() downloads static map tiles.
giscoR::gisco_attributions() provides GISCO attribution text.
Static map tiles and imagery:
addProviderEspTiles(),
esp_get_tiles(),
esp_make_provider()
esp_get_attributions("IGNBase.Todo")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.