Skip to contents

esp_get_attributions() gets the attribution of a tile provider defined by the type argument.

Usage

esp_get_attributions(type, options = NULL)

Arguments

type

This argument can be one of:

options

A named list containing additional options to pass to the query.

Value

A character string with the provider attribution, or NULL if no attribution is available.

See also

Static map tiles and imagery: addProviderEspTiles(), esp_get_tiles(), esp_make_provider()

Examples

esp_get_attributions("IGNBase.Todo")
#> [1] "CC BY 4.0 scne.es. Sistema Geográfico Nacional IGN"