esp_get_attributions() gets the attribution of a tile provider defined by
the type argument.
Arguments
- type
This argument can be one of:
The name of one of the pre-defined providers (see esp_tiles_providers).
A list with two named elements
idandqwith your own arguments. Seeesp_make_provider()and examples.
- options
A named list containing additional options to pass to the query.
See also
esp_get_tiles()downloads static map tiles.giscoR::gisco_attributions()provides GISCO attribution text.
Static map tiles and imagery:
addProviderEspTiles(),
esp_get_tiles(),
esp_make_provider()