This function returns an sf POINT locating the seat of
government for each municipality.
Note that this differs from the centroid of the boundaries of the
municipality, returned by esp_get_munic_siane().
Usage
esp_get_capimun(
year = Sys.Date(),
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
region = NULL,
munic = NULL,
moveCAN = TRUE,
rawcols = FALSE
)Source
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), http://www.ign.es/web/ign/portal. Years available are 2005 up to today.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Arguments
- year
Character string or number. Release year. It must use format
YYYY(assuming end of year) orYYYY-MM-DD. Historical information starts as of 2005.- epsg
Character string or number. Projection of the map: 4-digit EPSG code. One of:
"4258": ETRS89."4326": WGS84."3035": ETRS89 / ETRS-LAEA."3857": Pseudo-Mercator.
- cache
Logical. Whether to cache downloaded files. Defaults to
TRUE. See Caching.- update_cache
Logical. If
TRUE, refreshes the cached file and forces a new download. Defaults toFALSE.- cache_dir
Character string. A path to a cache directory. See Caching.
- verbose
A logical value. If
TRUEdisplays informational messages.- region
Optional. A vector of region names, NUTS or ISO codes (see
esp_dict_region_code()).- munic
Character string. A name or
regexexpression with the names of the required municipalities. UseNULLto return all municipalities.- moveCAN
A logical
TRUE/FALSEor a vector of coordinatesc(lat, lon). It places the Canary Islands close to Spain's mainland. Initial position can be adjusted using the vector of coordinates. See Displacing the Canary Islands inesp_move_can().- rawcols
Logical. If
TRUE, adds the raw columns of the resulting object as provided by IGN.
Value
An sf POINT object.
Details
When using region you can use and mix names and NUTS codes (levels 1, 2 or
3), ISO codes (corresponding to level 2 or 3) or "cpro"
(see esp_codelist).
When calling a higher level, such as a province, Autonomous Community, Autonomous City or NUTS 1 region, all municipalities of that level are added.
Caching
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
See also
CartoBase ANE boundaries and utilities:
esp_get_ccaa_siane(),
esp_get_countries_siane(),
esp_get_munic_siane(),
esp_get_prov_siane(),
esp_get_spain_siane(),
esp_siane_bulk_download()
Municipality-level datasets:
esp_get_munic(),
esp_get_munic_siane()
Examples
# \donttest{
# Compare municipality centroids against esp_get_capimun().
# Get the municipality boundary.
area <- esp_get_munic_siane(munic = "Valladolid", epsg = 3857)
# Area in km2.
print(paste0(round(as.double(sf::st_area(area)) / 1000000, 2), " km2"))
#> [1] "353.42 km2"
# Extract the centroid.
centroid <- sf::st_centroid(area)
#> Warning: st_centroid assumes attributes are constant over geometries
centroid$type <- "Centroid"
# Compare with capimun.
capimun <- esp_get_capimun(munic = "Valladolid", epsg = 3857)
capimun$type <- "Capimun"
# Join both point geometries.
points <- dplyr::bind_rows(centroid, capimun)
# Check on a plot.
library(ggplot2)
ggplot(points) +
geom_sf(data = area, fill = NA, color = "blue") +
geom_sf(data = points, aes(fill = type), size = 5, shape = 21) +
scale_fill_manual(values = c("green", "red")) +
labs(title = "Centroid vs. capimun")
# }