View source: R/esp-get-countries-siane.R
| esp_get_countries_siane | R Documentation |
This dataset contains worldwide country-level administrative boundaries.
The data included in this cartographic database do not imply any opinion of the IGN regarding its legal status.
esp_get_countries_siane(
year = Sys.Date(),
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
country = NULL
)
year |
Character string or number. Release year. It must use format
|
epsg |
Character string or number. Projection of the map: 4-digit EPSG code. One of:
|
cache |
Logical. Whether to cache downloaded files. Defaults to |
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
country |
Character vector of country codes. Accepts country names,
ISO3 country codes or ISO2 country codes. See also
|
A sf object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
giscoR::gisco_get_countries().
CartoBase ANE boundaries and utilities:
esp_get_capimun(),
esp_get_ccaa_siane(),
esp_get_munic_siane(),
esp_get_prov_siane(),
esp_get_spain_siane(),
esp_siane_bulk_download()
cntries <- esp_get_countries_siane()
library(ggplot2)
ggplot(cntries) +
geom_sf()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.