This dataset contains the administrative boundaries at country level of the world.
The data included in this cartographic database do not imply any opinion of the IGN regarding its legal status.
Usage
esp_get_countries_siane(
year = Sys.Date(),
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
country = NULL
)Source
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), http://www.ign.es/web/ign/portal. Years available are 2005 up to today.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Arguments
- year
Character string or number. Release year. It must use format
YYYY(assuming end of year) orYYYY-MM-DD. Historical information starts as of 2005.- epsg
Character string or number. Projection of the map: 4-digit EPSG code. One of:
"4258": ETRS89."4326": WGS84."3035": ETRS89 / ETRS-LAEA."3857": Pseudo-Mercator.
- cache
Logical. Whether to cache downloaded files. Defaults to
TRUE. See Caching.- update_cache
Logical. If
TRUE, refreshes the cached file and forces a new download. Defaults toFALSE.- cache_dir
Character string. A path to a cache directory. See Caching.
- verbose
A logical value. If
TRUEdisplays informational messages.- country
Character vector of country codes. It can be a vector of country names, ISO3 country codes or ISO2 country codes. See also
countrycode::countrycode().
Value
A sf object.
Caching
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
See also
giscoR::gisco_get_countries().
Datasets sourced from CartoBase ANE (Atlas Nacional de España):
esp_get_capimun(),
esp_get_ccaa_siane(),
esp_get_munic_siane(),
esp_get_prov_siane(),
esp_get_spain_siane(),
esp_siane_bulk_download()