Skip to contents

[Defunct]

This function is defunct because the source file is no longer available.

Usage

esp_get_grid_EEA(
  resolution = 100,
  type = "main",
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

resolution

Resolution of the grid in kilometers. Can be 1, 10 or 100.

type

Character. The geographic scope of the grid:

  • "main": Mainland Spain (default).

  • "canary": Canary Islands.

update_cache

Logical. If TRUE, refreshes the cached file and forces a new download. Defaults to FALSE.

cache_dir

Character string. A path to a cache directory. See Caching strategies section in esp_set_cache_dir().

verbose

logical. If TRUE displays informational messages.

Value

A sf POLYGON.