View source: R/esp-get-hydrobasin.R
| esp_get_hydrobasin | R Documentation |
River basin districts are the areas of land and sea, made up of one or more neighbouring river basins together with their associated groundwaters and coastal waters.
esp_get_hydrobasin(
epsg = 4258,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
resolution = c(3, 6.5, 10),
domain = c("land", "landsea")
)
epsg |
Character string or number. Projection of the map: 4-digit EPSG code. One of:
|
cache |
Logical. Whether to cache downloaded files. Defaults to |
update_cache |
Logical. If |
cache_dir |
Character string. A path to a cache directory. See Caching. |
verbose |
A logical value indicating whether to display informational messages. |
resolution |
Character string or number. Resolution of the geospatial data. One of:
|
domain |
Character string. Type of river basin district:
|
Metadata available on https://github.com/rOpenSpain/mapSpain/tree/sianedata/.
A sf object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Natural feature datasets:
esp_get_hypsobath(),
esp_get_landwater
hydroland <- esp_get_hydrobasin(domain = "land")
hydrolandsea <- esp_get_hydrobasin(domain = "landsea")
library(ggplot2)
ggplot(hydroland) +
geom_sf(data = hydrolandsea, fill = "skyblue4", alpha = 0.4) +
geom_sf(fill = "skyblue", alpha = 0.5) +
geom_sf_text(aes(label = rotulo),
size = 2, check_overlap = TRUE,
fontface = "bold",
family = "serif"
) +
coord_sf(
crs = 3857,
xlim = c(-9.5, 4.5),
ylim = c(35, 44)
) +
theme_void()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.