Dataset representing the hypsometry and bathymetry of Spain.
Hypsometry represents the elevation and depth of features of the Earth's surface relative to mean sea level.
Bathymetry is the measurement of the depth of water in oceans, rivers, or lakes.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), http://www.ign.es/web/ign/portal. Years available are 2005 up to today.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
Arguments
- epsg
Character string or number. Projection of the map: 4-digit EPSG code. One of:
"4258": ETRS89."4326": WGS84."3035": ETRS89 / ETRS-LAEA."3857": Pseudo-Mercator.
- cache
Logical. Whether to cache downloaded files. Default is
TRUE. See Caching strategies section inesp_set_cache_dir().- update_cache
Logical. If
TRUE, refreshes the cached file and forces a new download. Defaults toFALSE.- cache_dir
Character string. A path to a cache directory. See Caching strategies section in
esp_set_cache_dir().- verbose
logical. If
TRUEdisplays informational messages.- resolution
Character string or number. Resolution of the geospatial data. One of:
"6.5": 1:6.5 million.
"3": 1:3 million.
- spatialtype
Character string. Spatial type of the output. Use
"area"forPOLYGONor"line"forLINESTRING.
Value
A sf object.
Details
Metadata available on https://github.com/rOpenSpain/mapSpain/tree/sianedata/.
See also
Natural feature datasets:
esp_get_hydrobasin(),
esp_get_landwater
Examples
# \donttest{
# This code produces a plot and takes a few seconds to run.
library(ggplot2)
hypsobath <- esp_get_hypsobath()
# Tints from Wikipedia.
# https://en.wikipedia.org/wiki/Wikipedia:WikiProject_Maps/Conventions/
# Topographic_maps
levels <- sort(unique(hypsobath$val_inf))
# Create the manual palette.
br_bath <- length(levels[levels < 0])
br_terrain <- length(levels) - br_bath
pal <- c(
tidyterra::hypso.colors(br_bath, "wiki-2.0_bathy"),
tidyterra::hypso.colors(br_terrain, "wiki-2.0_hypso")
)
# Plot the Canary Islands.
ggplot(hypsobath) +
geom_sf(aes(fill = as.factor(val_inf)),
color = NA
) +
coord_sf(
xlim = c(-18.6, -13),
ylim = c(27, 29.5)
) +
scale_fill_manual(values = pal) +
guides(fill = guide_legend(
title = "Elevation",
direction = "horizontal",
label.position = "bottom",
title.position = "top",
nrow = 1
)) +
theme(legend.position = "bottom")
# Plot mainland Spain.
ggplot(hypsobath) +
geom_sf(aes(fill = as.factor(val_inf)),
color = NA
) +
coord_sf(
xlim = c(-9.5, 4.4),
ylim = c(35.8, 44)
) +
scale_fill_manual(values = pal) +
guides(fill = guide_legend(
title = "Elevation",
reverse = TRUE,
keyheight = 0.8
))
# }