Get provinces of Spain at a specified scale.
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/administrative-units.
Arguments
- prov
A vector of names, codes or both for provinces, or
NULLto get all the provinces. See Details.- moveCAN
A logical
TRUE/FALSEor a vector of coordinatesc(lat, lon). It places the Canary Islands close to Spain's mainland. Initial position can be adjusted using the vector of coordinates. See Displacing the Canary Islands inesp_move_can().- ...
Arguments passed on to
esp_get_nutsyearYear character string or number. Release year of the file. See
giscoR::gisco_get_nuts()for valid values.epsgCharacter string or number. Projection of the map: 4-digit EPSG code. One of:
"4258": ETRS89."4326": WGS84."3035": ETRS89 / ETRS-LAEA."3857": Pseudo-Mercator.
cacheLogical. Whether to cache downloaded files. Defaults to
TRUE. See Caching.update_cacheLogical. If
TRUE, refreshes the cached file and forces a new download. Defaults toFALSE.cache_dirCharacter string. A path to a cache directory. See Caching.
spatialtypeCharacter string. Type of geometry to be returned. Options available are:
"RG": regions, returned as aMULTIPOLYGON/POLYGONobject."LB": labels, returned as aPOINTobject.
extCharacter. Extension of the file (default
"gpkg"). SeegiscoR::gisco_get_nuts().verboseA logical value. If
TRUEdisplays informational messages.resolutionA character string or numeric value with the geospatial data resolution. One of:
"60": 1:60 million."20": 1:20 million."10": 1:10 million."03": 1:3 million."01": 1:1 million.
Value
A sf object.
Details
When using prov you can use and mix names and NUTS codes (levels 1, 2 or
3), ISO codes (corresponding to level 2 or 3) or "cpro" (see
esp_codelist).
Ceuta and Melilla are considered provinces in this dataset.
When calling a higher level (Autonomous Community or City, or NUTS 1), all provinces of that level are added.
Caching
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
See also
Datasets sourced from GISCO:
esp_get_ccaa(),
esp_get_munic(),
esp_get_nuts(),
esp_get_spain()
Examples
prov <- esp_get_prov()
library(ggplot2)
ggplot(prov) +
geom_sf() +
theme_minimal()
# \donttest{
# Random provinces.
random <- esp_get_prov(prov = c(
"Zamora", "Palencia", "ES-GR",
"ES521", "01"
))
ggplot(random) +
geom_sf(aes(fill = codauto), show.legend = FALSE, alpha = 0.5) +
scale_fill_manual(values = hcl.colors(nrow(random), "Spectral")) +
theme_minimal()
# All provinces of a zone plus one addition.
mix <- esp_get_prov(prov = c(
"Noroeste",
"Castilla y Leon", "La Rioja"
))
mix$ccaa <- esp_dict_region_code(
mix$codauto,
origin = "codauto"
)
ggplot(mix) +
geom_sf(aes(fill = ccaa), alpha = 0.5) +
scale_fill_discrete(type = hcl.colors(5, "Temps")) +
theme_classic()
# Available ISO codes.
allprovs <- esp_get_prov()
ggplot(allprovs) +
geom_sf(fill = NA) +
geom_sf_text(aes(label = iso2.prov.code),
check_overlap = TRUE,
fontface = "bold"
) +
coord_sf(crs = 3857) +
theme_void()
# }