View source: R/esp-get-spain.R
| esp_get_spain | R Documentation |
Returns the boundaries of Spain as a single sf POLYGON at a
specified scale.
esp_get_spain(moveCAN = TRUE, ...)
moveCAN |
A logical |
... |
Arguments passed on to
|
Dataset derived from NUTS data provided by GISCO. Check esp_get_nuts() for
details.
A sf POLYGON object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
GISCO NUTS distribution API: https://gisco-services.ec.europa.eu/distribution/v2/nuts/.
esp_get_spain_siane().
NUTS boundary datasets:
esp_get_nuts()
GISCO boundary data:
esp_get_ccaa(),
esp_get_munic(),
esp_get_nuts(),
esp_get_prov()
original_can <- esp_get_spain(moveCAN = FALSE)
# One row only.
original_can
library(ggplot2)
ggplot(original_can) +
geom_sf(fill = "grey70")
# Less resolution.
moved_can <- esp_get_spain(moveCAN = TRUE, resolution = 20)
ggplot(moved_can) +
geom_sf(fill = "grey70")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.