Skip to contents

Returns the boundaries of Spain as a single sf POLYGON at a specified scale.

Usage

esp_get_spain(moveCAN = TRUE, ...)

Arguments

moveCAN

A logical TRUE/FALSE or a vector of coordinates c(lat, lon). It places the Canary Islands close to Spain's mainland. Initial position can be adjusted using the vector of coordinates. See Displacing the Canary Islands in esp_move_can().

...

Arguments passed on to esp_get_nuts

year

Year character string or number. Release year of the file. See giscoR::gisco_get_nuts() for valid values.

epsg

Character string or number. Projection of the map: 4-digit EPSG code. One of:

cache

Logical. Whether to cache downloaded files. Defaults to TRUE. See Caching.

update_cache

Logical. If TRUE, refreshes the cached file and forces a new download. Defaults to FALSE.

cache_dir

Character string. A path to a cache directory. See Caching.

ext

Character. Extension of the file (default "gpkg"). See giscoR::gisco_get_nuts().

verbose

A logical value. If TRUE displays informational messages.

resolution

A character string or numeric value with the geospatial data resolution. One of:

  • "60": 1:60 million.

  • "20": 1:20 million.

  • "10": 1:10 million.

  • "03": 1:3 million.

  • "01": 1:1 million.

Value

A sf POLYGON object.

Details

Dataset derived from NUTS data provided by GISCO. Check esp_get_nuts() for details.

Caching

Functions that download data store files in cache_dir. When cache_dir is NULL, they use the active package cache, which defaults to a temporary directory. Set update_cache = TRUE to replace an existing cached file. See Caching strategies in esp_set_cache_dir() to configure a persistent cache.

See also

NUTS boundary datasets: esp_get_nuts()

Datasets sourced from GISCO: esp_get_ccaa(), esp_get_munic(), esp_get_nuts(), esp_get_prov()

Examples

# \donttest{
original_can <- esp_get_spain(moveCAN = FALSE)

# One row only.
original_can
#> Simple feature collection with 1 feature and 18 fields
#> Geometry type: MULTIPOLYGON
#> Dimension:     XY
#> Bounding box:  xmin: -18.15996 ymin: 27.63846 xmax: 4.320228 ymax: 43.78924
#> Geodetic CRS:  ETRS89
#> # A tibble: 1 × 19
#>   NUTS_ID LEVL_CODE CNTR_CODE NAME_LATN NUTS_NAME MOUNT_TYPE URBN_TYPE
#> * <chr>       <int> <chr>     <chr>     <chr>          <int>     <int>
#> 1 ES              0 ES        España    España            NA        NA
#> # ℹ 12 more variables: COAST_TYPE <int>, NAME_ENGL <chr>, NAME_FREN <chr>,
#> #   ISO3_CODE <chr>, SVRG_UN <chr>, CAPT <chr>, EU_STAT <chr>, EFTA_STAT <chr>,
#> #   CC_STAT <chr>, NAME_GERM <chr>, geo <chr>, geometry <MULTIPOLYGON [°]>

library(ggplot2)

ggplot(original_can) +
  geom_sf(fill = "grey70")


# Less resolution.
moved_can <- esp_get_spain(moveCAN = TRUE, resolution = 20)

ggplot(moved_can) +
  geom_sf(fill = "grey70")

# }