View source: R/esp-get-spain-siane.R
| esp_get_spain_siane | R Documentation |
Returns the boundaries of Spain as a single sf POLYGON.
esp_get_spain_siane(moveCAN = TRUE, ...)
moveCAN |
A logical |
... |
Arguments passed on to
|
A sf object.
Functions that download data store files in cache_dir. When cache_dir
is NULL, they use the active package cache, which defaults to a temporary
directory. Set update_cache = TRUE to replace an existing cached file.
See Caching strategies in esp_set_cache_dir() to configure a
persistent cache.
CartoBase ANE (Atlas Nacional de España) provided by Instituto Geográfico Nacional (IGN), https://www.ign.es/web/ign/portal. Data are available from 2005 to the present.
Copyright: https://centrodedescargas.cnig.es/CentroDescargas/cartobase-ane
Always acknowledge authorship using the following statements:
When the original digital product is not modified or altered, use one of the following statements:
CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
CartoBase ANE 2006-2024 CC-BY 4.0 Instituto Geográfico Nacional.
When a new product is generated:
Obra derivada de CartoBase ANE 2006-2024 CC-BY 4.0 ign.es.
Data distributed through the sianedata data branch, see
https://github.com/rOpenSpain/mapSpain/tree/sianedata.
esp_get_spain().
CartoBase ANE boundaries and utilities:
esp_get_capimun(),
esp_get_ccaa_siane(),
esp_get_countries_siane(),
esp_get_munic_siane(),
esp_get_prov_siane(),
esp_siane_bulk_download()
original_can <- esp_get_spain_siane(moveCAN = FALSE)
# One row only.
original_can
library(ggplot2)
ggplot(original_can) +
geom_sf(fill = "grey70")
# Less resolution.
moved_can <- esp_get_spain_siane(moveCAN = TRUE, resolution = 10)
ggplot(moved_can) +
geom_sf(fill = "grey70")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.